# -*- coding: utf-8 -*-
#
# Configuration file for the Sphinx documentation builder.
#
# This file does only contain a selection of the most common options. For a
# full list see the documentation:
# http://www.sphinx-doc.org/en/stable/config

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
import os
import sys

# -- Apidoc ------------------------------------------------------------------

from sphinx.ext import apidoc
sys.path.insert(0, os.path.abspath('../../'))
apidoc.main(['--force', '-M', '-e', '-E', '-T', '-o', './apidoc', '../../paragraph', '../../paragraph/tests/*'])

# -- Project information -----------------------------------------------------

project = 'paragraph'
copyright = '2019, Othoz GmbH'
author = 'Othoz GmbH'

# The short X.Y version
# Mathias: Will be supplied from outside through the build pipeline
version = ''
# The full version, including alpha/beta/rc tags
release = ''


# -- General configuration ---------------------------------------------------

# If your documentation needs a minimal Sphinx version, state it here.
#
# needs_sphinx = '1.0'

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    'sphinx.ext.autodoc',
    # Typehints are currently deactivated as this would require to maintain a separate requirements.txt for readthedocs.
    # readthedocs will most likely support Pipfiles in the future, then we can reactivate this feature
    # https://github.com/readthedocs/readthedocs.org/issues/3181
    'sphinx.ext.napoleon',  # must be loaded before 'sphinx_autodoc_typehints' according to https://github.com/agronholm/sphinx-autodoc-typehints
    'sphinx_autodoc_typehints',
    # 'sphinx.ext.mathjax'
]

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# The suffix(es) of source filenames.
# You can specify multiple suffix as a list of string:
#
# source_suffix = ['.rst', '.md']
source_suffix = '.rst'

# The master toctree document.
master_doc = 'index'

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
language = None

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path .
exclude_patterns = ["apidoc/paragraph.rst"]

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = 'sphinx'


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = 'sphinx_rtd_theme'

html_logo = 'othoz-logo.png'

html_last_updated_fmt = ''

# Theme options are theme-specific and customize the look and feel of a theme
# further.  For a list of options available for each theme, see the
# documentation.
#
html_theme_options = {
    'canonical_url': '',
    'analytics_id': '',
    'logo_only': False,
    'display_version': True,
    'prev_next_buttons_location': 'bottom',
    # Toc options
    'collapse_navigation': False,
    'sticky_navigation': True,
    'navigation_depth': 3
}

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
# html_static_path = ['_static']

# Custom sidebar templates, must be a dictionary that maps document names
# to template names.
#
# The default sidebars (for documents that don't match any pattern) are
# defined by theme itself.  Builtin themes are using these templates by
# default: ``['localtoc.html', 'relations.html', 'sourcelink.html',
# 'searchbox.html']``.
#
# html_sidebars = {}


# -- Options for HTMLHelp output ---------------------------------------------

# Output file base name for HTML help builder.
htmlhelp_basename = 'paragraphdoc'

# -- Extension configuration -------------------------------------------------

# Configure autodoc to take class documentation from both the docstring in the class as well as __init__
# Seen strictly one of both (the default is class) would suffice but a large part of our codebase has
# the docstring in __init__. While we are in the process of moving all documentation out of __init__ to
# the class level we instruct Sphinx to take it from both places.
autoclass_content = "both"

# In the generated documentation we want the order of the functions / classes the same as in the Python source file
# as we usually logically organize the source file in a meaningful way. Sphinx's default is to to sort the output alphabetically.
autodoc_member_order = "bysource"
